#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_id_readiness_checks
short_description: Resource module for Network Device
  Images Id Readiness Checks
description:
  - Manage operation create of the resource Network
    Device Images Id Readiness Checks. - > Triggers
    an on-demand network device update readiness check,
    where system-defined pre-checks will be performed.
    Upon task completion, the task API response's `resultLocation`
    attribute will contain the URL for fetching the
    validation result.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Network device identifier.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) TriggerUpdateReadinessForNetworkDevice
    description: Complete reference of the TriggerUpdateReadinessForNetworkDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!trigger-update-readiness-for-network-device
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.trigger_update_readiness_for_network_device,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceImages/{id}/readinessChecks,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_images_id_readiness_checks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device
short_description: Resource module for Network Device
description:
  - Manage operations create, update and delete of the
    resource Network Device.
  - Adds the device with given credential. - > This
    API allows any network device that is not currently
    provisioned to be removed from the inventory. Important
    Devices currently provisioned cannot be deleted.
    To delete a provisioned device, the device must
    be first deprovisioned. - > Update the credentials,
    management IP address of a given device or a set
    of devices in Catalyst Center and trigger an inventory
    sync.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cleanConfig:
    description: CleanConfig query parameter. Selecting
      the clean up configuration option will attempt
      to remove device settings that were configured
      during the addition of the device to the inventory
      and site assignment. Please note that this operation
      is different from deprovisioning. It does not
      remove configurations that were pushed during
      device provisioning.
    type: bool
    version_added: 4.0.0
  cliTransport:
    description: CLI transport. Supported values telnet,
      ssh. Required if type is NETWORK_DEVICE.
    type: str
  computeDevice:
    description: Compute Device or not. Options are
      true / false.
    type: bool
  enablePassword:
    description: CLI enable password of the device.
      Required if device is configured to use enable
      password.
    type: str
  extendedDiscoveryInfo:
    description: This field holds that info as whether
      to add device with canned data or not. Supported
      values DISCOVER_WITH_CANNED_DATA.
    type: str
  httpPassword:
    description: HTTP password of the device / API key
      for Meraki Dashboard. Required if type is MERAKI_DASHBOARD
      or COMPUTE_DEVICE.
    type: str
  httpPort:
    description: HTTP port of the device. Required if
      type is COMPUTE_DEVICE.
    type: str
  httpSecure:
    description: Flag to select HTTP / HTTPS protocol.
      Options are true / false. True for HTTPS and false
      for HTTP. Default is true.
    type: bool
  httpUserName:
    description: HTTP Username of the device. Required
      if type is COMPUTE_DEVICE.
    type: str
  id:
    description: Id path parameter. Device ID.
    type: str
  ipAddress:
    description: IP Address of the device. Required
      if type is NETWORK_DEVICE, COMPUTE_DEVICE or THIRD_PARTY_DEVICE.
    elements: str
    type: list
  merakiOrgId:
    description: Selected Meraki organization for which
      the devices needs to be imported. Required if
      type is MERAKI_DASHBOARD.
    elements: str
    type: list
  netconfPort:
    description: Netconf Port of the device. CliTransport
      must be 'ssh' if netconf is provided. Netconf
      port is required for eWLC.
    type: str
  password:
    description: CLI Password of the device. Required
      if type is NETWORK_DEVICE.
    type: str
  serialNumber:
    description: Serial Number of the Device. Required
      if extendedDiscoveryInfo is 'DISCOVER_WITH_CANNED_DATA'.
    type: str
  snmpAuthPassphrase:
    description: SNMPv3 auth passphrase of the device.
      Required if snmpMode is authNoPriv or authPriv.
    type: str
  snmpAuthProtocol:
    description: SNMPv3 auth protocol. Supported values
      sha, md5. Required if snmpMode is authNoPriv or
      authPriv.
    type: str
  snmpMode:
    description: SNMPv3 mode. Supported values noAuthnoPriv,
      authNoPriv, authPriv. Required if snmpVersion
      is v3.
    type: str
  snmpPrivPassphrase:
    description: SNMPv3 priv passphrase. Required if
      snmpMode is authPriv.
    type: str
  snmpPrivProtocol:
    description: SNMPv3 priv protocol. Supported values
      AES128. Required if snmpMode is authPriv.
    type: str
  snmpROCommunity:
    description: SNMP Read Community of the device.
      If snmpVersion is v2, at least one of snmpROCommunity
      and snmpRwCommunity is required.
    type: str
  snmpRwCommunity:
    description: SNMP Write Community of the device.
      If snmpVersion is v2, at least one of snmpROCommunity
      and snmpRwCommunity is required.
    type: str
  snmpRetry:
    description: SNMP retry count. Max value supported
      is 3. Default is Global SNMP retry (if exists)
      or 3.
    type: int
  snmpTimeout:
    description: SNMP timeout in seconds. Max value
      supported is 300. Default is Global SNMP timeout
      (if exists) or 5.
    type: int
  snmpUserName:
    description: SNMPV3 user name of the device. Required
      if snmpVersion is v3.
    type: str
  snmpVersion:
    description: SNMP version. Values supported v2,
      v3. Required if type is NETWORK_DEVICE, COMPUTE_DEVICE
      or THIRD_PARTY_DEVICE.
    type: str
  type:
    description: Type of device being added. Default
      is NETWORK_DEVICE.
    type: str
  updateMgmtIPaddressList:
    description: Network Device's updateMgmtIPaddressList.
    elements: dict
    suboptions:
      existMgmtIpAddress:
        description: ExistMgmtIpAddress IP Address of
          the device.
        type: str
      newMgmtIpAddress:
        description: New IP Address to be Updated.
        type: str
    type: list
  userName:
    description: CLI user name of the device. Required
      if type is NETWORK_DEVICE.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      AddDeviceKnowYourNetwork
    description: Complete reference of the AddDeviceKnowYourNetwork
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-device-know-your-network
  - name: Cisco DNA Center documentation for Devices
      DeleteDeviceById
    description: Complete reference of the DeleteDeviceById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-device-by-id
  - name: Cisco DNA Center documentation for Devices
      UpdateDeviceDetails
    description: Complete reference of the UpdateDeviceDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-device-details
notes:
  - SDK Method used are
    devices.Devices.add_device,
    devices.Devices.delete_device_by_id,
    devices.Devices.sync_devices,
  - Paths used are
    post /dna/intent/api/v1/network-device,
    delete /dna/intent/api/v1/network-device/{id},
    put
    /dna/intent/api/v1/network-device,
    - Removed 'managementIpAddress'
    options in v4.3.0.
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cliTransport: string
    computeDevice: true
    enablePassword: string
    extendedDiscoveryInfo: string
    httpPassword: string
    httpPort: string
    httpSecure: true
    httpUserName: string
    ipAddress:
      - string
    merakiOrgId:
      - string
    netconfPort: string
    password: string
    serialNumber: string
    snmpAuthPassphrase: string
    snmpAuthProtocol: string
    snmpMode: string
    snmpPrivPassphrase: string
    snmpPrivProtocol: string
    snmpROCommunity: string
    snmpRwCommunity: string
    snmpRetry: 0
    snmpTimeout: 0
    snmpUserName: string
    snmpVersion: string
    type: string
    userName: string
- name: Update all
  cisco.dnac.network_device:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cliTransport: string
    computeDevice: true
    enablePassword: string
    extendedDiscoveryInfo: string
    httpPassword: string
    httpPort: string
    httpSecure: true
    httpUserName: string
    ipAddress:
      - string
    merakiOrgId:
      - string
    netconfPort: string
    password: string
    serialNumber: string
    snmpAuthPassphrase: string
    snmpAuthProtocol: string
    snmpMode: string
    snmpPrivPassphrase: string
    snmpPrivProtocol: string
    snmpROCommunity: string
    snmpRwCommunity: string
    snmpRetry: 0
    snmpTimeout: 0
    snmpUserName: string
    snmpVersion: string
    type: string
    updateMgmtIPaddressList:
      - existMgmtIpAddress: string
        newMgmtIpAddress: string
    userName: string
- name: Delete by id
  cisco.dnac.network_device:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    cleanConfig: true
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: virtual_network_health_summaries_info
short_description: Information module for Virtual Network
  Health Summaries
description:
  - Get all Virtual Network Health Summaries. - > Get
    a paginated list of Virtual Networks with health
    summary. Layer 2 Virtual Networks are only included
    in health reporting for EVPN protocol deployments.
    The special Layer 3 VN called "INFRA_VN" is also
    not included for user access through Assurance virtualNetworkHealthSummaries
    APIS. Please find INFRA_VN related health metrics
    under /data/api/v1/fabricSiteHealthSummaries Ex
    attributes "pubsubInfraVnGoodHealthPercentage" and
    "bgpPeerInfraVnScoreGoodHealthPercentage" .
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of entity Uuids.
        (Ex."6bef213c-19ca-4170-8375-b694e251101c")
        Examples id=6bef213c-19ca-4170-8375-b694e251101c
        (single entity uuid requested) id=6bef213c-19ca-4170-8375-
        b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9&id=2541e9a7-b80d-4955-8aa2-79b233318ba0
        (multiple entity uuid with '&' separator).
    type: str
  vnLayer:
    description:
      - VnLayer query parameter. VN Layer information
        covering Layer 3 or Layer 2 VNs.
    type: str
  attribute:
    description:
      - Attribute query parameter. The interested fields
        in the request. For valid attributes, verify
        the documentation.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. This is an optional parameter
        which can be passed to get one or more of the
        specific health data summaries associated with
        virtual networks.
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  SiteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadListOfVirtualNetworksWithTheirHealthSummary
    description: Complete reference of the ReadListOfVirtualNetworksWithTheirHealthSummary
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-virtual-networks-with-their-health-summary
notes:
  - SDK Method used are
    sda.Sda.read_list_of_virtual_networks_with_their_health_summary,
  - Paths used are
    get /dna/data/api/v1/virtualNetworkHealthSummaries,
"""

EXAMPLES = r"""
---
- name: Get all Virtual Network Health Summaries
  cisco.dnac.virtual_network_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    id: string
    vnLayer: string
    attribute: string
    view: string
    siteHierarchy: string
    SiteHierarchyId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "vlan": "string",
          "vnid": "string",
          "layer": "string",
          "associatedL3Vn": "string",
          "totalEndpoints": 0,
          "totalFabricSites": 0,
          "goodHealthPercentage": 0,
          "goodHealthDeviceCount": 0,
          "totalHealthDeviceCount": 0,
          "fairHealthDeviceCount": 0,
          "poorHealthDeviceCount": 0,
          "noHealthDeviceCount": 0,
          "vnFabricControlPlaneGoodHealthPercentage": 0,
          "vnFabricControlPlaneTotalDeviceCount": 0,
          "vnFabricControlPlaneGoodHealthDeviceCount": 0,
          "vnFabricControlPlanePoorHealthDeviceCount": 0,
          "vnFabricControlPlaneFairHealthDeviceCount": 0,
          "vnFabricControlPlaneNoHealthDeviceCount": 0,
          "vnServicesHealthPercentage": 0,
          "vnServicesTotalDeviceCount": 0,
          "vnServicesGoodHealthDeviceCount": 0,
          "vnServicesPoorHealthDeviceCount": 0,
          "vnServicesFairHealthDeviceCount": 0,
          "vnServicesNoHealthDeviceCount": 0,
          "vnExitHealthPercentage": 0,
          "vnExitTotalDeviceCount": 0,
          "vnExitGoodHealthDeviceCount": 0,
          "vnExitPoorHealthDeviceCount": 0,
          "vnExitFairHealthDeviceCount": 0,
          "vnExitNoHealthDeviceCount": 0,
          "vnStatusHealthPercentage": 0,
          "vnStatusTotalDeviceCount": 0,
          "vnStatusGoodHealthDeviceCount": 0,
          "vnStatusPoorHealthDeviceCount": 0,
          "vnStatusFairHealthDeviceCount": 0,
          "vnStatusNoHealthDeviceCount": 0,
          "pubsubSessionGoodHealthPercentage": 0,
          "pubsubSessionTotalDeviceCount": 0,
          "pubsubSessionGoodHealthDeviceCount": 0,
          "pubsubSessionPoorHealthDeviceCount": 0,
          "pubsubSessionFairHealthDeviceCount": 0,
          "pubsubSessionNoHealthDeviceCount": 0,
          "multiCastGoodHealthPercentage": 0,
          "multiCastTotalDeviceCount": 0,
          "multiCastGoodHealthDeviceCount": 0,
          "multiCastPoorHealthDeviceCount": 0,
          "multiCastFairHealthDeviceCount": 0,
          "internetAvailGoodHealthPercentage": 0,
          "internetAvailTotalDeviceCount": 0,
          "internetAvailGoodHealthDeviceCount": 0,
          "internetAvailPoorHealthDeviceCount": 0,
          "internetAvailFairHealthDeviceCount": 0,
          "internetAvailNoHealthDeviceCount": 0,
          "bgpPeerGoodHealthPercentage": 0,
          "bgpPeerTotalDeviceCount": 0,
          "bgpPeerGoodHealthDeviceCount": 0,
          "bgpPeerPoorHealthDeviceCount": 0,
          "bgpPeerFairHealthDeviceCount": 0,
          "bgpPeerNoHealthDeviceCount": 0,
          "vniGoodHealthPercentage": 0,
          "vniTotalDeviceCount": 0,
          "vniGoodHealthDeviceCount": 0,
          "vniPoorHealthDeviceCount": 0,
          "vniFairHealthDeviceCount": 0,
          "vniNoHealthDeviceCount": 0,
          "networkProtocol": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_extranet_policies
short_description: Resource module for Sda Extranet
  Policies
description:
  - Manage operations create, update and delete of the
    resource Sda Extranet Policies.
  - Adds an extranet policy based on user input.
  - Deletes an extranet policy based on id.
  - Deletes extranet policies based on user input.
  - Updates an extranet policy based on user input.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  extranetPolicyName:
    description: ExtranetPolicyName query parameter.
      Name of the extranet policy.
    type: str
  id:
    description: Id path parameter. ID of the extranet
      policy.
    type: str
  payload:
    description: Sda Extranet Policies's payload.
    elements: dict
    suboptions:
      extranetPolicyName:
        description: Name of the existing extranet policy
          (updating this field is not allowed).
        type: str
      fabricIds:
        description: IDs of the fabric sites associated
          with this extranet policy.
        elements: str
        type: list
      id:
        description: ID of the existing extranet policy
          (updating this field is not allowed).
        type: str
      providerVirtualNetworkName:
        description: Name of the existing provider virtual
          network (updating this field is not allowed).
        type: str
      subscriberVirtualNetworkNames:
        description: Name of the subscriber virtual
          networks.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA AddExtranetPolicy
    description: Complete reference of the AddExtranetPolicy
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-extranet-policy
  - name: Cisco DNA Center documentation for SDA DeleteExtranetPolicies
    description: Complete reference of the DeleteExtranetPolicies
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-extranet-policies
  - name: Cisco DNA Center documentation for SDA DeleteExtranetPolicyById
    description: Complete reference of the DeleteExtranetPolicyById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-extranet-policy-by-id
  - name: Cisco DNA Center documentation for SDA UpdateExtranetPolicy
    description: Complete reference of the UpdateExtranetPolicy
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-extranet-policy
notes:
  - SDK Method used are
    sda.Sda.add_extranet_policy,
    sda.Sda.delete_extranet_policy_by_id,
    sda.Sda.update_extranet_policy,
  - Paths used are
    post /dna/intent/api/v1/sda/extranetPolicies,
    delete /dna/intent/api/v1/sda/extranetPolicies,
    delete /dna/intent/api/v1/sda/extranetPolicies/{id},
    put /dna/intent/api/v1/sda/extranetPolicies,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.sda_extranet_policies:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    extranetPolicyName: string
- name: Update all
  cisco.dnac.sda_extranet_policies:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - extranetPolicyName: string
        fabricIds:
          - string
        id: string
        providerVirtualNetworkName: string
        subscriberVirtualNetworkNames:
          - string
- name: Create
  cisco.dnac.sda_extranet_policies:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - extranetPolicyName: string
        fabricIds:
          - string
        providerVirtualNetworkName: string
        subscriberVirtualNetworkNames:
          - string
- name: Delete by id
  cisco.dnac.sda_extranet_policies:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_info
short_description: Information module for Images
description:
  - Get all Images. - > A list of available images for
    the specified site is provided. The default value
    of the site is set to global. The list includes
    images that have been imported onto the disk, as
    well as the latest and suggested images from Cisco.com.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - >
        SiteId query parameter. Site identifier to get
        the list of all available products under the
        site. The default value is the global site.
        See https //developer.cisco.com/docs/dna-center/get-site
        for `siteId`.
    type: str
  productNameOrdinal:
    description:
      - >
        ProductNameOrdinal query parameter. The product
        name ordinal is a unique value for each network
        device product. The productNameOrdinal can be
        obtained from the response of API `/dna/intent/api/v1/siteWiseProductNames`.
    type: float
  supervisorProductNameOrdinal:
    description:
      - >
        SupervisorProductNameOrdinal query parameter.
        The supervisor engine module ordinal is a unique
        value for each supervisor module. The `supervisorProductNameOrdinal`
        can be obtained from the response of API `/dna/intent/api/v1/siteWiseProductNames`.
    type: float
  imported:
    description:
      - >
        Imported query parameter. When the value is
        set to `true`, it will include physically imported
        images. Conversely, when the value is set to
        `false`, it will include image records from
        the cloud. The identifier for cloud images can
        be utilized to download images from Cisco.com
        to the disk.
    type: bool
  name:
    description:
      - >
        Name query parameter. Filter with software image
        or add-on name. Supports partial case-insensitive
        search. A minimum of 3 characters is required
        for the search.
    type: str
  version:
    description:
      - >
        Version query parameter. Filter with image version.
        Supports partial case-insensitive search. A
        minimum of 3 characters is required for the
        search.
    type: str
  golden:
    description:
      - >
        Golden query parameter. When set to `true`,
        it will retrieve the images marked as tagged
        golden. When set to `false`, it will retrieve
        the images marked as not tagged golden.
    type: bool
  integrity:
    description:
      - >
        Integrity query parameter. Filter with verified
        images using Integrity Verification Available
        values UNKNOWN, VERIFIED.
    type: str
  hasAddonImages:
    description:
      - >
        HasAddonImages query parameter. When set to `true`,
        it will retrieve the images which have add-on
        images. When set to `false`, it will retrieve
        the images which do not have add-on images.
    type: bool
  isAddonImages:
    description:
      - >
        IsAddonImages query parameter. When set to `true`,
        it will retrieve the images that an add-on image.
        When set to `false`, it will retrieve the images
        that are not add-on images.
    type: bool
  offset:
    description:
      - >
        Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. The minimum value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. The minimum and maximum
        values are 1 and 500, respectively.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) ReturnsListOfSoftwareImages
    description: Complete reference of the ReturnsListOfSoftwareImages
      API.
    link: https://developer.cisco.com/docs/dna-center/#!returns-list-of-software-images
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.returns_list_of_software_images,
  - Paths used are
    get /dna/intent/api/v1/images,
"""

EXAMPLES = r"""
---
- name: Get all Images
  cisco.dnac.images_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
    productNameOrdinal: 0
    supervisorProductNameOrdinal: 0
    imported: true
    name: string
    version: string
    golden: true
    integrity: string
    hasAddonImages: true
    isAddonImages: true
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "imported": true,
          "name": "string",
          "version": "string",
          "imageType": "string",
          "recommended": "string",
          "ciscoLatest": true,
          "integrityStatus": "string",
          "isAddonImage": true,
          "hasAddonImages": true,
          "goldenTaggingDetails": [
            {
              "deviceRoles": [
                "string"
              ],
              "deviceTags": [
                "string"
              ],
              "inheritedSiteId": "string",
              "inheritedSiteName": "string"
            }
          ],
          "productNames": [
            {
              "id": "string",
              "productName": "string",
              "productNameOrdinal": 0,
              "supervisorProductName": "string",
              "supervisorProductNameOrdinal": 0
            }
          ],
          "isGoldenTagged": true
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: diagnostic_validation_workflows_info
short_description: Information module for Diagnostic
  Validation Workflows
description:
  - Get all Diagnostic Validation Workflows.
  - Get Diagnostic Validation Workflows by id. - > Retrieves
    the workflows that have been successfully submitted
    and are currently available. This is sorted by `submitTime`.
  - Retrieves workflow details for a workflow id.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - StartTime query parameter. Workflows started
        after the given time (as milliseconds since
        UNIX epoch).
    type: float
  endTime:
    description:
      - EndTime query parameter. Workflows started before
        the given time (as milliseconds since UNIX epoch).
    type: float
  runStatus:
    description:
      - >
        RunStatus query parameter. Execution status
        of the workflow. If the workflow is successfully
        submitted, runStatus is `PENDING`. If the workflow
        execution has started, runStatus is `IN_PROGRESS`.
        If the workflow executed is completed with all
        validations executed, runStatus is `COMPLETED`.
        If the workflow execution fails while running
        validations, runStatus is `FAILED`.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. Specifies the maximum
        number of workflows to return per page. Must
        be an integer between 1 and 500, inclusive.
    type: int
  id:
    description:
      - Id path parameter. Workflow id.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Health
      and Performance RetrievesTheListOfValidationWorkflows
    description: Complete reference of the RetrievesTheListOfValidationWorkflows
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-validation-workflows
  - name: Cisco DNA Center documentation for Health
      and Performance RetrievesValidationWorkflowDetails
    description: Complete reference of the RetrievesValidationWorkflowDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-validation-workflow-details
notes:
  - SDK Method used are
    health_and_performance.HealthAndPerformance.retrieves_the_list_of_validation_workflows,
    health_and_performance.HealthAndPerformance.retrieves_validation_workflow_details,
  - Paths used are
    get /dna/intent/api/v1/diagnosticValidationWorkflows,
    get /dna/intent/api/v1/diagnosticValidationWorkflows/{id},
"""

EXAMPLES = r"""
---
- name: Get all Diagnostic Validation Workflows
  cisco.dnac.diagnostic_validation_workflows_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    runStatus: string
    offset: 0
    limit: 0
  register: result
- name: Get Diagnostic Validation Workflows by id
  cisco.dnac.diagnostic_validation_workflows_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "description": "string",
        "runStatus": "string",
        "submitTime": 0,
        "validationSetIds": [
          "string"
        ],
        "releaseVersion": "string",
        "validationSetsRunDetails": [
          {
            "validationSetId": "string",
            "startTime": 0,
            "endTime": 0,
            "validationStatus": "string",
            "version": "string",
            "validationRunDetails": [
              {
                "validationId": "string",
                "validationName": "string",
                "validationMessage": "string",
                "validationStatus": "string"
              }
            ]
          }
        ],
        "validationStatus": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_service_insertions
short_description: Resource module for Security Service
  Insertions
description:
  - Manage operation create of the resource Security
    Service Insertions. - > Enables Security Service
    Insertion SSI on a fabric site within a network.
    Security Service Insertion allows the integration
    of security services, such as firewalls, into the
    fabric network, ensuring that traffic within Virtual
    Networks VNs is routed through these security devices.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  siteId:
    description: The ID of the fabric site where the
      service insertion is configured.
    type: str
  virtualNetworks:
    description: Security Service Insertions's virtualNetworks.
    elements: dict
    suboptions:
      devices:
        description: Security Service Insertions's devices.
        elements: dict
        suboptions:
          id:
            description: The unique identifier of the
              network device.
            type: str
          layer3Handoffs:
            description: Security Service Insertions's
              layer3Handoffs.
            elements: dict
            suboptions:
              firewallIpV4AddressWithMask:
                description: The IPv4 address and subnet
                  mask of the firewall.
                type: str
            type: list
        type: list
      name:
        description: Name of the virtual network associated
          with the fabric site.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA CreateSecurityServiceInsertionOnASpecificFabricSite
    description: Complete reference of the CreateSecurityServiceInsertionOnASpecificFabricSite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-security-service-insertion-on-a-specific-fabric-site
notes:
  - SDK Method used are
    sda.Sda.create_security_service_insertion_on_a_specific_fabric_site,
  - Paths used are
    post /dna/intent/api/v1/securityServiceInsertions,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_service_insertions:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    siteId: string
    virtualNetworks:
      - devices:
          - id: string
            layer3Handoffs:
              - firewallIpV4AddressWithMask: string
        name: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_replacements_info
short_description: Information module for Network Device
  Replacements
description:
  - Get all Network Device Replacements. - > Retrieve
    the list of device replacements with replacement
    details. Filters can be applied based on faulty
    device name, faulty device platform, faulty device
    serial number, replacement device platform, replacement
    device serial number, device replacement status,
    device family.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  family:
    description:
      - Family query parameter. Faulty device family.
    type: str
  faultyDeviceName:
    description:
      - FaultyDeviceName query parameter. Faulty device
        name.
    type: str
  faultyDevicePlatform:
    description:
      - FaultyDevicePlatform query parameter. Faulty
        device platform.
    type: str
  faultyDeviceSerialNumber:
    description:
      - FaultyDeviceSerialNumber query parameter. Faulty
        device serial number.
    type: str
  replacementDevicePlatform:
    description:
      - ReplacementDevicePlatform query parameter. Replacement
        device platform.
    type: str
  replacementDeviceSerialNumber:
    description:
      - ReplacementDeviceSerialNumber query parameter.
        Replacement device serial number.
    type: str
  replacementStatus:
    description:
      - >
        ReplacementStatus query parameter. Device replacement
        status. Available values MARKED_FOR_REPLACEMENT,
        NETWORK_READINESS_REQUESTED, NETWORK_READINESS_FAILED,
        READY_FOR_REPLACEMENT, REPLACEMENT_SCHEDULED,
        REPLACEMENT_IN_PROGRESS, REPLACED, ERROR. Replacement
        status 'MARKED_FOR_REPLACEMENT' - The faulty
        device has been marked for replacement. 'NETWORK_READINESS_REQUESTED'
        - Initiated steps to shut down neighboring device
        interfaces and create a DHCP server on the uplink
        neighbor if the faulty device is part of a fabric
        setup. 'NETWORK_READINESS_FAILED' - Preparation
        of the network failed. Neighboring device interfaces
        were not shut down, and the DHCP server on the
        uplink neighbor was not created. 'READY_FOR_REPLACEMENT'
        - The network is prepared for the faulty device
        replacement. Neighboring device interfaces are
        shut down, and the DHCP server on the uplink
        neighbor is set up. 'REPLACEMENT_SCHEDULED'
        - Device replacement has been scheduled. 'REPLACEMENT_IN_PROGRESS'
        - Device replacement is currently in progress.
        'REPLACED' - Device replacement was successful.
        'ERROR' - Device replacement has failed.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page. Maximum value can be
        500.
    type: int
  sortBy:
    description:
      - >
        SortBy query parameter. A property within the
        response to sort by. Available values id, creationTime,
        family, faultyDeviceId, fautyDeviceName, faultyDevicePlatform,
        faultyDeviceSerialNumber, replacementDevicePlatform,
        replacementDeviceSerialNumber, replacementTime.
    type: str
  sortOrder:
    description:
      - >
        SortOrder query parameter. Whether ascending
        or descending order should be used to sort the
        response. Available values ASC, DESC.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Device
      Replacement RetrieveTheStatusOfAllTheDeviceReplacementWorkflows
    description: Complete reference of the RetrieveTheStatusOfAllTheDeviceReplacementWorkflows
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-the-status-of-all-the-device-replacement-workflows
notes:
  - SDK Method used are
    device_replacement.DeviceReplacement.retrieve_the_status_of_all_the_device_replacement_workflows,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceReplacements,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Replacements
  cisco.dnac.network_device_replacements_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    family: string
    faultyDeviceName: string
    faultyDevicePlatform: string
    faultyDeviceSerialNumber: string
    replacementDevicePlatform: string
    replacementDeviceSerialNumber: string
    replacementStatus: string
    offset: 0
    limit: 0
    sortBy: string
    sortOrder: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "creationTime": 0,
          "family": "string",
          "faultyDeviceId": "string",
          "faultyDeviceName": "string",
          "faultyDevicePlatform": "string",
          "faultyDeviceSerialNumber": "string",
          "id": "string",
          "neighborDeviceId": "string",
          "replacementDevicePlatform": "string",
          "replacementDeviceSerialNumber": "string",
          "replacementStatus": "string",
          "replacementTime": 0,
          "workflow": {
            "id": "string",
            "name": "string",
            "workflowStatus": "string",
            "startTime": 0,
            "endTime": 0,
            "steps": [
              {
                "name": "string",
                "status": "string",
                "statusMessage": "string",
                "startTime": 0,
                "endTime": 0
              }
            ]
          }
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-
# Copyright (c) 2025, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

"""Ansible module to perform update Health score KPI's in Cisco Catalyst Center."""
from __future__ import absolute_import, division, print_function

__metaclass__ = type
__author__ = ["Megha Kandari, Madhan Sankaranarayanan"]

DOCUMENTATION = r"""
---
module: assurance_device_health_score_settings_workflow_manager
short_description: Resource module for managing assurance
  Health score settings in Cisco Catalyst Center.
description:
  - Manages assurance Health score settings in Cisco
    Catalyst Center.
  - It supports updating configurations for Health score
    settings functionalities.
  - This module interacts with Cisco Catalyst Center's
    Assurance settings to configure thresholds, rules,
    KPIs, and more for health score monitoring.
  - The health score can be customized based on device
    type.
  - The network device's health score is determined
    by the lowest score among all included KPIs.
  - To disable a KPI from impacting the overall device
    health, you can exclude it from the health score
    calculation.
  - Health score setting is not applicable for Third
    Party Devices.
version_added: '6.31.0'
extends_documentation_fragment:
  - cisco.dnac.workflow_manager_params
author: Megha Kandari (@kandarimegha) Madhan Sankaranarayanan
  (@madhansansel)
options:
  config_verify:
    description: >
      Set to `True` to enable configuration verification
      on Cisco Catalyst Center after applying the playbook
      config. This will ensure that the system validates
      the configuration state after the change is applied.
    type: bool
    default: false
  state:
    description: >
      Specifies the desired state for the configuration.
      If `merged`, the module will update the configuration
      modifying existing ones.
    type: str
    choices: [merged]
    default: merged
  config:
    description: >
      A list of settings and parameters for managing
      network issues in Cisco Catalyst Center, including
      synchronization with health thresholds, priority,
      KPI enablement, and threshold values.
    type: list
    elements: dict
    required: true
    suboptions:
      device_health_score:
        description: >
          Configures the health score settings for network
          devices. Defines thresholds for KPIs like
          CPU UTILIZATION, MEMORY UTILIZATION, etc.
        type: dict
        required: true
        suboptions:
          device_family:
            description: >
              Specifies the device family to which the
              health score applies.
                required:
              true
                choices:
                  - ROUTER
                  - SWITCH_AND_HUB
                  - WIRELESS_CONTROLLER
                  - UNIFIED_AP
                  - WIRELESS_CLIENT
                  - WIRED_CLIENT
          kpi_name:
            description: >
              The name of the Key Performance Indicator
              (KPI) to be monitored (e.g., LINK ERROR).
              Must be one of the valid KPI names for
              the specified device family. choices:
                ROUTER:
                    -
              BGP Session from Border to Control Plane
              (BGP)
                    -
              BGP Session from Border to Control Plane
              (PubSub)
                    -
              BGP Session from Border to Peer Node for
              INFRA VN
                    -
              BGP Session from Border to Peer Node
                    -
              BGP Session from Border to Transit Control
              Plane
                    -
              BGP Session to Spine
                    -
              Cisco TrustSec environment data download
              status
                    -
              CPU Utilization
                    -
              Extended Node Connectivity
                    -
              Fabric Control Plane Reachability
                    -
              Fabric Multicast RP Reachability
                    -
              Inter-device Link Availability
                    -
              Internet Availability
                    -
              Link Discard
                    -
              Link Error
                    -
              Link Utilization
                    -
              LISP Session from Border to Transit Site
              Control Plane
                    -
              LISP Session Status
                    -
              Memory Utilization
                    -
              Peer Status
                    -
              Pub-Sub Session from Border to Transit
              Site Control Plane
                    -
              Pub-Sub Session Status for INFRA VN
                    -
              Pub-Sub Session Status
                    -
              Remote Internet Availability
                    -
              VNI Status
                SWITCH_AND_HUB:
                    -
              AAA server reachability
                    -
              BGP Session from Border to Control Plane
              (BGP)
                    -
              BGP Session from Border to Control Plane
              (PubSub)
                    -
              BGP Session from Border to Peer Node for
              INFRA VN
                    -
              BGP Session from Border to Peer Node
                    -
              BGP Session from Border to Transit Control
              Plane
                    -
              BGP Session to Spine
                    -
              Cisco TrustSec environment data download
              status
                    -
              CPU Utilization
                    -
              Extended Node Connectivity
                    -
              Fabric Control Plane Reachability
                    -
              Fabric Multicast RP Reachability
                    -
              Inter-device Link Availability
                    -
              Internet Availability
                    -
              Link Discard
                    -
              Link Error
                    -
              LISP Session from Border to Transit Site
              Control Plane
                    -
              LISP Session Status
                    -
              Memory Utilization
                    -
              Peer Status
                    -
              Pub-Sub Session from Border to Transit
              Site Control Plane
                    -
              Pub-Sub Session Status for INFRA VN
                    -
              Pub-Sub Session Status
                    -
              Remote Internet Availability
                    -
              VNI Status
                WIRELESS_CONTROLLER:
                    -
              Fabric Control Plane Reachability
                    -
              Free Mbuf
                    -
              Free Timer
                    -
              Link Error
                    -
              LISP Session Status
                    -
              Memory Utilization
                    -
              Packet Pool
                    -
              WQE Pool
                UNIFIED_AP:
                    -
              Air Quality 2.4 GHz
                    -
              Air Quality 5 GHz
                    -
              Air Quality 6 GHz
                    -
              CPU Utilization
                    -
              Interference 2.4 GHz
                    -
              Interference 5 GHz
                    -
              Interference 6 GHz
                    -
              Link Error
                    -
              Memory Utilization
                    -
              Noise 2.4 GHz
                    -
              Noise 5 GHz
                    -
              Noise 6 GHz
                    -
              RF Utilization 2.4 GHz
                    -
              RF Utilization 5 GHz
                    -
              RF Utilization 6 GHz
                WIRELESS_CLIENT:
                    -
              Connectivity RSSI
                    -
              Connectivity SNR
                WIRED_CLIENT:
                    -
              Link Error
            type: str
            required: true
          include_for_overall_health:
            description: >
              Boolean value indicating whether this
              KPI should be included in the overall
              health score calculation.
            type: bool
            required: true
          threshold_value:
            description: >
              The threshold value that, when exceeded,
              will affect the health score.
            type: int
          synchronize_to_issue_threshold:
            description: >
              Boolean value indicating whether the threshold
              should synchronize with issue resolution
              thresholds.
            type: bool
requirements:
  - dnacentersdk >= 2.8.6
  - python >= 3.9
notes:
  - SDK Method used are
    devices.AssuranceSettings.get_all_health_score_definitions_for_given_filters,
    devices.AssuranceSettings.update_health_score_definitions
  - Paths used are
    post /dna/intent/api/v1/health_scoreDefinitions/${id},
    post /dna/intent/api/v1/health_scoreDefinitions/bulkUpdate
"""

EXAMPLES = r"""
---
- hosts: dnac_servers
  vars_files:
    - credentials.yml
  gather_facts: false
  connection: local
  tasks:
    - name: Update Health score and threshold settings
      cisco.dnac. assurance_device_health_score_settings_workflow_manager:
        dnac_host: "{{ dnac_host }}"
        dnac_port: "{{ dnac_port }}"
        dnac_username: "{{ dnac_username }}"
        dnac_password: "{{ dnac_password }}"
        dnac_verify: "{{ dnac_verify }}"
        dnac_debug: "{{ dnac_debug }}"
        dnac_version: "{{ dnac_version }}"
        dnac_log: true
        dnac_log_level: debug
        dnac_log_append: true
        state: merged
        config_verify: true
        config:
          - device_health_score:
              - device_family: SWITCH_AND_HUB  # required field
                kpi_name: CPU Utilization  # required field
                include_for_overall_health: true  # required field
                threshold_value: 90
                synchronize_to_issue_threshold: false
- hosts: dnac_servers
  vars_files:
    - credentials.yml
  gather_facts: false
  connection: local
  tasks:
    - name: Update Health score and threshold settings
      cisco.dnac. assurance_device_health_score_settings_workflow_manager:
        dnac_host: "{{ dnac_host }}"
        dnac_port: "{{ dnac_port }}"
        dnac_username: "{{ dnac_username }}"
        dnac_password: "{{ dnac_password }}"
        dnac_verify: "{{ dnac_verify }}"
        dnac_debug: "{{ dnac_debug }}"
        dnac_version: "{{ dnac_version }}"
        dnac_log: true
        dnac_log_level: debug
        dnac_log_append: true
        state: merged
        config_verify: true
        config:
          - device_health_score:
              - device_family: ROUTER  # required field
                kpi_name: Link Error  # required field
                include_for_overall_health: true  # required field
                threshold_value: 60
                synchronize_to_issue_threshold: false
- hosts: dnac_servers
  vars_files:
    - credentials.yml
  gather_facts: false
  connection: local
  tasks:
    - name: Update Health score and threshold settings
      cisco.dnac. assurance_device_health_score_settings_workflow_manager:
        dnac_host: "{{ dnac_host }}"
        dnac_port: "{{ dnac_port }}"
        dnac_username: "{{ dnac_username }}"
        dnac_password: "{{ dnac_password }}"
        dnac_verify: "{{ dnac_verify }}"
        dnac_debug: "{{ dnac_debug }}"
        dnac_version: "{{ dnac_version }}"
        dnac_log: true
        dnac_log_level: debug
        dnac_log_append: true
        state: merged
        config_verify: true
        config:
          - device_health_score:
              - device_family: UNIFIED_AP  # required field
                kpi_name: Interference 6 GHz  # required field
                include_for_overall_health: true  # required field
                threshold_value: 80
                synchronize_to_issue_threshold: false
"""


RETURN = r"""
#Case 1: Successful updation of health_score
response_1:
  description: A dictionary or list with the response returned by the Cisco Catalyst Center Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
          "id": "string",
          "name": "string",
          "displayName": "string",
          "deviceFamily": "string",
          "description": "string",
          "includeForOverallHealth": "boolean",
          "definitionStatus": "string",
          "thresholdValue": "number",
          "synchronizeToIssueThreshold": "boolean",
          "lastModified": "string"
      },
      "version": "string"
    }
"""


from ansible.module_utils.basic import AnsibleModule
from ansible_collections.cisco.dnac.plugins.module_utils.dnac import (
    DnacBase,
    validate_list_of_dicts,
)


class Healthscore(DnacBase):
    """Class containing member attributes for Assurance health score setting workflow manager module"""

    def __init__(self, module):
        super().__init__(module)
        self.supported_states = ["merged"]
        self.result["response"] = [
            {"device_health_score_settings": {"response": {}, "msg": {}}},
        ]
        self.create_issue, self.update_issue, self.no_update_issue = [], [], []

    def validate_input(self):
        """
        Validate the fields provided in the playbook.
        Checks the configuration provided in the playbook against a predefined specification
        to ensure it adheres to the expected structure and data types.

        Parameters:
            self: The instance of the class containing the 'config' attribute to be validated.
            self.config (dict): A dictionary representing the playbook configuration that needs validation.
            The 'config' should be structured according to a specification, with keys such as 'device_health_score'.
            Each key in the configuration should match the predefined data types and structure defined in `temp_spec`.


        Returns:
            The method updates these attributes of the instance:
                - self.msg: A message describing the validation result.
                - self.status: The status of the validation ('success' or 'failed').
                - self.validated_config (dict): The validated configuration, if successful, otherwise the method returns early with failure.
        """

        temp_spec = {
            "device_health_score": {
                "type": "list",
                "elements": "dict",
                "name": {"type": "str", "required": True},
                "device_family": {"type": "str", "required": True},
                "include_for_overall_health": {"type": "bool", "required": True},
                "threshold_value": {"type": "int", "required": False},
                "synchronize_to_issue_threshold": {"type": "bool", "required": False},
            }
        }

        if not self.config:
            self.msg = "The playbook configuration is empty or missing."
            self.set_operation_result("failed", False, self.msg, "ERROR")
            return self

        valid_temp, invalid_params = validate_list_of_dicts(self.config, temp_spec)

        if invalid_params:
            self.msg = "The playbook contains invalid parameters: {0}".format(
                invalid_params
            )
            self.set_operation_result("failed", False, self.msg, "ERROR")
            return self

        self.validated_config = valid_temp
        self.msg = "Successfully validated playbook configuration parameters using 'validate_input': {0}".format(
            str(valid_temp)
        )
        self.log(self.msg, "INFO")

        return self

    def input_data_validation(self, config):
        """
        Additional validation to check if the provided input assurance data is correct
        and as per the UI Cisco Catalyst Center.
        This function checks that the provided KPIs (Key Performance Indicators) and parameters are valid
        for the specified device families.

        Parameters:
            self (object): An instance of a class for interacting with Cisco Catalyst Center.
            config (list or dict): Input data containing assurance details.

        Returns:
            object: Returns the current instance with validation results.
            self.msg(str): A message indicating the validation result, either an error or success.
            self.status(str): The validation status, which will be 'failed' in case of invalid data and 'success' if the validation is successful.

        Description:
            Validates the given assurance data by iterating through the nested structure
            and ensuring the KPIs and parameters comply with defined rules.
        """
        errormsg = []
        device_family_to_kpi = {
            "ROUTER": {
                "include_for_overall_health": [
                    "Fabric Multicast RP Reachability",
                    "Inter-device Link Availability",
                    "Internet Availability",
                    "LISP Session from Border to Transit Site Control Plane",
                    "LISP Session Status",
                    "Peer Status",
                    "BGP Session from Border to Control Plane (BGP)",
                    "BGP Session from Border to Control Plane (PubSub)",
                    "BGP Session from Border to Peer Node for INFRA VN",
                    "BGP Session from Border to Peer Node",
                    "BGP Session from Border to Transit Control Plane",
                    "BGP Session to Spine",
                    "Cisco TrustSec environment data download status",
                    "Extended Node Connectivity",
                    "Fabric Control Plane Reachability",
                    "Pub-Sub Session from Border to Transit Site Control Plane",
                    "Pub-Sub Session Status for INFRA VN",
                    "Pub-Sub Session Status",
                    "Remote Internet Availability",
                    "VNI Status",
                ],
                "include_Threshold_and_sync": [
                    "Link Discard",
                    "Link Error",
                    "Link Utilization",
                    "Memory Utilization",
                    "CPU Utilization",
                ],
                "include_Threshold": [],
            },
            "SWITCH_AND_HUB": {
                "include_for_overall_health": [
                    "AAA server reachability",
                    "BGP Session from Border to Control Plane (BGP)",
                    "BGP Session from Border to Control Plane (PubSub)",
                    "BGP Session from Border to Peer Node for INFRA VN",
                    "BGP Session from Border to Peer Node",
                    "BGP Session from Border to Transit Control Plane",
                    "BGP Session to Spine",
                    "Cisco TrustSec environment data download status",
                    "Extended Node Connectivity",
                    "Fabric Control Plane Reachability",
                    "Fabric Multicast RP Reachability",
                    "Inter-device Link Availability",
                    "Internet Availability",
                    "LISP Session from Border to Transit Site Control Plane",
                    "LISP Session Status",
                    "Peer Status",
                    "Pub-Sub Session from Border to Transit Site Control Plane",
                    "Pub-Sub Session Status for INFRA VN",
                    "Pub-Sub Session Status",
                    "Remote Internet Availability",
                    "VNI Status",
                ],
                "include_Threshold_and_sync": [
                    "CPU Utilization",
                    "Link Discard",
                    "Link Error",
                    "Memory Utilization",
                ],
                "include_Threshold": [],
            },
            "WIRELESS_CONTROLLER": {
                "include_for_overall_health": [
                    "Fabric Control Plane Reachability",
                    "LISP Session Status",
                    "Packet Pool",
                    "WQE Pool",
                ],
                "include_Threshold_and_sync": [
                    "Memory Utilization",
                ],
                "include_Threshold": [
                    "Free Mbuf",
                    "Free Timer",
                    "Link Error",
                ],
            },
            "UNIFIED_AP": {
                "include_for_overall_health": [],
                "include_Threshold_and_sync": [
                    "CPU Utilization",
                    "Interference 2.4 GHz",
                    "Interference 5 GHz",
                    "Interference 6 GHz",
                    "Memory Utilization",
                    "Noise 2.4 GHz",
                    "Noise 5 GHz",
                    "Noise 6 GHz",
                    "RF Utilization 2.4 GHz",
                    "RF Utilization 5 GHz",
                    "RF Utilization 6 GHz",
                ],
                "include_Threshold": [
                    "Air Quality 2.4 GHz",
                    "Air Quality 5 GHz",
                    "Air Quality 6 GHz",
                    "Link Error",
                ],
            },
            "WIRELESS_CLIENT": {
                "include_for_overall_health": [],
                "include_Threshold_and_sync": [
                    "Connectivity RSSI",
                ],
                "include_Threshold": [
                    "Connectivity SNR",
                ],
            },
            "WIRED_CLIENT": {
                "include_for_overall_health": [],
                "include_Threshold_and_sync": [],
                "include_Threshold": [
                    "Link Error",
                ],
            },
        }

        normalized_health_scores = []
        if isinstance(config, dict) and "device_health_score" in config:
            self.log(
                "Condition met: config is a dict and contains 'device_health_score'",
                "INFO",
            )
            normalized_health_scores.extend(config["device_health_score"])
        elif isinstance(config, list):
            self.log("Condition met: config is a list", "INFO")
            for item in config:
                if "device_health_score" in item:
                    self.log(
                        "Sub-condition met: item in list contains 'device_health_score'. Value: {}".format(
                            item["device_health_score"]
                        ),
                        "INFO",
                    )
                    normalized_health_scores.extend(item["device_health_score"])
        else:
            self.msg = "Invalid configuration format provided. Ensure 'device_health_score' is present."
            self.log(self.msg, "ERROR")
            self.set_operation_result(
                "failed", False, self.msg, "ERROR"
            ).check_return_status()

        for entry in normalized_health_scores:
            device_family = entry.get("device_family")
            kpi_name = entry.get("kpi_name")
            include_for_overall_health = entry.get("include_for_overall_health", False)
            threshold_value = entry.get("threshold_value")
            synchronize_to_issue_threshold = entry.get(
                "synchronize_to_issue_threshold", False
            )
            self.log(
                "Extracted Values - device_family: {}, kpi_name: {}, include_for_overall_health: {}, "
                "threshold_value: {}, synchronize_to_issue_threshold: {}".format(
                    device_family,
                    kpi_name,
                    include_for_overall_health,
                    threshold_value,
                    synchronize_to_issue_threshold,
                ),
                "INFO",
            )

            if not device_family or device_family not in device_family_to_kpi:
                errormsg.append(
                    "Device_Family: Invalid or missing Device Family '{}'.".format(
                        device_family
                    )
                )
                continue

            valid_kpis = device_family_to_kpi[device_family]
            if not kpi_name:
                errormsg.append("kpi_name: KPI Name is missing.")
            else:
                if (
                    kpi_name not in valid_kpis["include_for_overall_health"]
                    and kpi_name not in valid_kpis["include_Threshold_and_sync"]
                    and kpi_name not in valid_kpis["include_Threshold"]
                ):
                    errormsg.append(
                        "kpi_name: Invalid KPI '{}' for Device Family '{}'.".format(
                            kpi_name, device_family
                        )
                    )
                else:
                    category = (
                        "include_for_overall_health"
                        if kpi_name in valid_kpis["include_for_overall_health"]
                        else "include_Threshold_and_sync"
                    )

                    if category == "include_for_overall_health" and (
                        threshold_value or synchronize_to_issue_threshold
                    ):
                        errormsg.append(
                            "'threshold_value' or 'synchronize_to_issue_threshold not applicable for KPI '{}''.".format(
                                kpi_name
                            )
                        )
                    if (
                        category == "include_Threshold"
                        and synchronize_to_issue_threshold
                    ):
                        errormsg.append(
                            "'synchronize_to_issue_threshold' is not applicable for KPI '{}' under 'include_Threshold_and_sync'.".format(
                                kpi_name
                            )
                        )
                    self.log(
                        "KPI '{}' belongs to category '{}' for Device Family '{}'".format(
                            kpi_name, category, device_family
                        ),
                        "INFO",
                    )

        if len(errormsg) > 0:
            self.msg = "Invalid parameters in playbook config: {}".format(errormsg)
            self.log(self.msg, "ERROR")
            self.set_operation_result(
                "failed", False, self.msg, "ERROR"
            ).check_return_status()

        self.msg = "Successfully validated config params: {}".format(config)
        self.log(self.msg, "INFO")
        return self

    def health_score_obj_params(self, get_object):
        """
        Get the required comparison obj_params value

        Parameters:
            get_object (str) - identifier for the required obj_params
            self (object): The instance of the class that calls this method.

        Returns:
            list - A list of value for comparison.
            None - If an invalid `get_object` is provided, logs an error and returns None.
        """

        try:
            if get_object == "device_health_score_settings":
                return [
                    ("name", "name"),
                    ("device_family", "device_family"),
                    ("include_for_overall_health", "include_for_overall_health"),
                    ("threshold_value", "threshold_value"),
                    (
                        "synchronize_to_issue_threshold",
                        "synchronize_to_issue_threshold",
                    ),
                ]

            error_message = "Received an unexpected value for 'get_object': {0}".format(
                get_object
            )
            self.log(error_message, "ERROR")
            self.set_operation_result("failed", False, error_message, "ERROR")
        except Exception as e:
            self.log("Received exception: {}".format(e), "CRITICAL")

        return None

    def get_want(self, config):
        """
        Retrieve and store assurance Health score details from playbook configuration.

        Parameters:
            self (object): An instance of a class used for interacting with Cisco Catalyst Center.
            config (dict): The configuration dictionary containing image import and other details.

        Returns:
            self: The current instance of the class with updated 'want' attributes.
        """

        want = {"device_health_score": config.get("device_health_score", [])}

        kpi_name = {
            "Link Error": "linkErrorThreshold",  # WIRED_CLIENT and # UNIFIED_AP and # WIRELESS_CLIENT # ROUTER
            "Connectivity RSSI": "rssiThreshold",  # WIRELESS_CLIENT
            "Connectivity SNR": "snrThreshold",  # WIRELESS_CLIENT
            "Air Quality 2.4 GHz": "rf_airQuality_2_4GThreshold",  # UNIFIED_AP
            "Air Quality 5 GHz": "rf_airQuality_5GThreshold",  # UNIFIED_AP
            "Air Quality 6 GHz": "rf_airQuality_6GThreshold",  # UNIFIED_AP
            "CPU Utilization": "cpuUtilizationThreshold",  # SWITCH_AND_HUB and # ROUTER and # UNIFIED_AP and # WIRELESS_CONTROLLER
            "Interference 2.4 GHz": "rf_interference_2_4GThreshold",  # UNIFIED_AP
            "Interference 5 GHz": "rf_interference_5GThreshold",  # UNIFIED_AP
            "Interference 6 GHz": "rf_interference_6GThreshold",  # UNIFIED_AP
            "Noise 2.4 GHz": "rf_noise_2_4GThreshold",  # UNIFIED_AP
            "Noise 5 GHz": "rf_noise_5GThreshold",  # UNIFIED_AP
            "Noise 6 GHz": "rf_noise_6GThreshold",  # UNIFIED_AP
            "RF Utilization 2.4 GHz": "rf_utilization_2_4GThreshold",  # UNIFIED_AP
            "RF Utilization 5 GHz": "rf_utilization_5GThreshold",  # UNIFIED_AP
            "RF Utilization 6 GHz": "rf_utilization_6GThreshold",  # UNIFIED_AP
            "Free Mbuf": "freeMbufThreshold",  # WIRELESS_CONTROLLER
            "Free Timer": "freeTimerThreshold",  # WIRELESS_CONTROLLER
            "Packet Pool": "packetPool",  # WIRELESS_CONTROLLER
            "WQE Pool": "WQEPool",  # WIRELESS_CONTROLLER
            "AAA server reachability": "aaaServerReachability",  # SWITCH_AND_HUB
            "BGP Session from Border to Control Plane (BGP)": "bgpBgpSiteThreshold",  # SWITCH_AND_HUB and # ROUTER
            "BGP Session from Border to Control Plane (PubSub)": "bgpPubsubSiteThreshold",  # SWITCH_AND_HUB and # ROUTER
            "BGP Session from Border to Peer Node for INFRA VN": "bgpPeerInfraVnThreshold",  # SWITCH_AND_HUB and # ROUTER
            "BGP Session from Border to Peer Node": "bgpPeerThreshold",  # SWITCH_AND_HUB and # ROUTER
            "BGP Session from Border to Transit Control Plane": "bgpTcpThreshold",  # SWITCH_AND_HUB and # ROUTER
            "BGP Session to Spine": "bgpEvpnThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Cisco TrustSec environment data download status": "ctsEnvDataThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Fabric Control Plane Reachability": "fabricReachability",  # SWITCH_AND_HUB and # ROUTER and # WIRELESS_CONTROLLER
            "Fabric Multicast RP Reachability": "multicastRPReachability",  # SWITCH_AND_HUB and # ROUTER
            "Extended Node Connectivity": "fpcLinkScoreThreshold",  # ROUTER and # WIRELESS_CONTROLLER
            "Inter-device Link Availability": "infraLinkAvailabilityThreshold",  # SWITCH_AND_HUB
            "Internet Availability": "defaultRouteThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Link Discard": "linkDiscardThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Link Utilization": "linkUtilizationThreshold",  # SWITCH_AND_HUB and # ROUTER
            "LISP Session from Border to Transit Site Control Plane": "lispTransitConnScoreThreshold",  # SWITCH_AND_HUB and # ROUTER
            "LISP Session Status": "lispCpConnScoreThreshold",  # SWITCH_AND_HUB and # ROUTER and # WIRELESS_CONTROLLER
            "Memory Utilization": "memoryUtilizationThreshold",  # SWITCH_AND_HUB and # ROUTER and # WIRELESS_CONTROLLER and # UNIFIED_AP
            "Peer Status": "peerThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Pub-Sub Session from Border to Transit Site Control Plane": "pubsubTransitSessionScoreThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Pub-Sub Session Status for INFRA VN": "pubsubInfraVNSessionScoreThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Pub-Sub Session Status": "pubsubSessionThreshold",  # SWITCH_AND_HUB and # ROUTER
            "Remote Internet Availability": "remoteRouteThreshold",  # SWITCH_AND_HUB and # ROUTER
            "VNI Status": "vniStatusThreshold",  # SWITCH_AND_HUB and # ROUTER
        }

        # Define validation rules for KPI names and device families
        validation_rules = {
            "Connectivity RSSI": {
                "device_family": "WIRELESS_CLIENT",
                "range": (-128, 0),
            },
            "Connectivity SNR": {"device_family": "WIRELESS_CLIENT", "range": (1, 40)},
        }
        self.log(want["device_health_score"])
        for health_score in want["device_health_score"]:
            name = health_score["kpi_name"]

            if name not in kpi_name:
                self.log("Unknown KPI name: {}".format(name), "ERROR")
                continue  # Skip unknown KPI names

            health_score["kpi_name"] = kpi_name[name]

            # Validate threshold values based on KPI name and device family
            rule = validation_rules.get(name)
            if rule and health_score.get("device_family") == rule["device_family"]:
                threshold_value = health_score.get("threshold_value")
                min_val, max_val = rule["range"]
                if threshold_value is None or not (
                    min_val <= threshold_value <= max_val
                ):
                    self.msg = "Threshold value for {} should be between {} and {} dBm.".format(
                        name, min_val, max_val
                    )
                    self.log("Validation failed: {}".format(self.msg), "CRITICAL")
                    self.set_operation_result("failed", False, self.msg, "ERROR")
                    return self  # Exit early on failure

        self.want = want
        self.log("Desired State (want): {0}".format(str(self.want)), "INFO")
        return self

    def get_have(self, config):
        """
        Get the current assurance Health score and associated information from the Cisco Catalyst Center
        based on the provided playbook details.

        Parameters:
        self (object): The instance interacting with Cisco Catalyst Center.
        config (dict): The configuration dictionary containing health score details.

        Returns:
        self: The current instance with updated 'have' attributes.
        """
        self.log("Starting to retrieve assurance health score details...", "INFO")
        device_health_score_details = config.get("device_health_score", [])

        if not device_health_score_details:
            self.msg = "No device_health_score details provided in the configuration."
            self.set_operation_result("failed", False, self.msg, "ERROR")

        have = []

        for index, health_score_details in enumerate(
            device_health_score_details, start=1
        ):
            self.log(
                "Processing entry {0}: {1}".format(index, health_score_details), "DEBUG"
            )
            if "kpi_name" in health_score_details:
                health_score_details["name"] = health_score_details.pop("kpi_name")
                self.log(
                    "Renamed 'kpi_name' to 'name' in entry {0}".format(index), "DEBUG"
                )

            device_family = health_score_details.get("device_family")
            if not device_family:
                self.log("{0}: Missing 'device_family' field.".format(index), "WARNING")
                self.msg = "Missing 'device_family' field."
                self.set_operation_result("failed", False, self.msg, "ERROR")

            self.log(
                "Fetching KPI details for device family '{0}' in entry {1}".format(
                    device_family, index
                ),
                "INFO",
            )

            kpi_details = self.get_kpi_details(device_family, health_score_details)

            if not kpi_details:
                self.msg = (
                    "No matching KPI details found for device family '{0}'".format(
                        device_family
                    )
                )
                self.set_operation_result("failed", False, self.msg, "ERROR")
                return self

            have.append(kpi_details)

        key_replacements = {
            "deviceFamily": "device_family",
            "includeForOverallHealth": "include_for_overall_health",
            "thresholdValue": "threshold_value",
            "synchronizeToIssueThreshold": "synchronize_to_issue_threshold",
        }

        for index, item in enumerate(have, start=1):
            for old_key, new_key in key_replacements.items():
                if old_key in item:
                    item[new_key] = item.pop(old_key)
                    self.log(
                        "Renamed '{0}' to '{1}' in entry {2}".format(
                            old_key, new_key, index
                        ),
                        "DEBUG",
                    )

        self.have = have

        self.log("Current State (have): {0}".format(self.have), "INFO")
        self.msg = "Successfully retrieved the details from the system."
        self.log(self.msg)
        return self

    def get_kpi_details(self, device_family, health_score_details):
        """
        Retrieve the KPI name based on the device family by calling the 'Get all health score definitions for given filters' API.

        Parameters:
        device_family (str): The device family for which KPI details are to be fetched.
        health_score_details (dict): The details of the health score for which KPI information is needed.

        Returns:
        kpi: The KPI details for the given device family and health score name if found.
        None: If no matching KPI details are found or if there is an exception during the API call.

        """
        self.log("Retrieving KPI for device family '{0}'".format(device_family))

        total_response = []
        try:
            for include_for_overall_health in [True, False]:
                response = self.dnac._exec(
                    family="devices",
                    function="get_all_health_score_definitions_for_given_filters",
                    params={
                        "deviceType": device_family,
                        "includeForOverallHealth": include_for_overall_health,
                    },
                )
                if isinstance(response.get("response"), list):
                    total_response.extend(response.get("response"))
            self.log(
                "Retrieved {0} KPI records for device family '{1}'".format(
                    len(total_response), device_family
                ),
                "DEBUG",
            )
        except Exception as msg:
            self.msg = "Exception occurred while getting KPI details: {0}".format(msg)
            self.log(self.msg, "ERROR")
            self.set_operation_result("failed", False, self.msg, "ERROR")
            return None

        if not isinstance(response, dict):
            self.msg = "Failed to retrieve KPI details - Response is not a dictionary"
            self.log(self.msg, "CRITICAL")
            self.set_operation_result("failed", False, self.msg, "ERROR")
            return None

        kpi_details = total_response

        if not kpi_details:
            self.msg = "No KPI details found for device family '{0}'".format(
                device_family
            )
            self.log(self.msg, "ERROR")
            self.set_operation_result("failed", False, self.msg, "ERROR")
            return None

        for kpi in kpi_details:
            if kpi.get("deviceFamily") == device_family and kpi.get(
                "name"
            ) == health_score_details.get("name"):
                self.log(
                    "KPI details for device family '{0}' and KPI '{1}': {2}".format(
                        device_family, health_score_details.get("name"), kpi
                    ),
                    "INFO",
                )
                return kpi

        self.msg = "No KPI found for device family '{0}' and KPI name '{1}'".format(
            device_family, kpi_details
        )
        self.log(self.msg, "ERROR")
        self.set_operation_result("failed", False, self.msg, "ERROR")
        return None

    def get_diff_merged(self, config):
        """
        Update Assurance Health score configurations in Cisco Catalyst Center based on the playbook details

        Parameters:
            config (list of dict) - Playbook details containing Assurance Health score information.

        Returns:
            self - The current object with Assurance health score information.
        """
        self.log("Starting get_diff_merged with provided config", "INFO")
        device_health_score_details = config.get("device_health_score")
        if not device_health_score_details:
            self.log(
                "No device_health_score details found in config. Skipping update.",
                "WARNING",
            )
            return self

        self.log("Updating health score settings with provided details", "INFO")
        self.update_health_score_settings(
            device_health_score_details
        ).check_return_status()

        self.log("Successfully completed get_diff_merged", "INFO")
        return self

    def update_health_score_settings(self, device_health_score_details):
        """
        Update the device Health score settings in Cisco Catalyst Center.

        This method compares the current Health score settings (`self.have`) with the desired Health score settings (`device_health_score_details`)
        from the playbook configuration. If there are any differences, it updates the Health score settings in Cisco Catalyst Center. It also checks if
        an update is needed for each setting, and if not, it logs that no update is required for that specific Health score setting.

        Parameters:
            device_health_score_details (list of dict): List of dictionaries containing the Health score settings that need to be updated.
                Each dictionary must include the following keys:
                - "name" (str): The name of the Health score setting.
                - "include_for_overall_health" (bool): Indicates if the Health score is included for overall health.
                - "threshold_value" (int): The threshold value for the Health score.
                - "synchronize_to_issue_threshold" (bool): Indicates if the Health score should be synchronized to issue threshold.

        Returns:
            self: The current instance of the class with updated Health score settings. If any setting fails to update, the operation will
                be marked as "failed", and the method will return early.
        """
        self.log("Starting update_health_score_settings with provided details", "INFO")
        updated_health_score_settings = []
        result_health_score_settings = self.result.get("response")[0].get(
            "device_health_score_settings"
        )

        if result_health_score_settings is None:
            self.log(
                "Failed to retrieve existing health score settings. Aborting update.",
                "ERROR",
            )
            self.set_operation_result(
                "failed", False, "Missing existing health score settings", "ERROR"
            )
            return self

        for health_score_setting in device_health_score_details:
            name = health_score_setting.get("name")
            if name is None:
                self.msg = (
                    "Missing required parameter 'name' in device_health_score_details"
                )
                self.set_operation_result("failed", False, self.msg, "ERROR")
                return self

            self.log("Processing health score setting: {0}".format(name), "DEBUG")
            health_score_obj_params = self.health_score_obj_params(
                "device_health_score_settings"
            )

            for item in self.have:
                if health_score_setting.get("name") == item.get(
                    "name"
                ) and health_score_setting.get("device_family") == item.get(
                    "device_family"
                ):
                    health_score_params = {}
                    if not self.requires_update(
                        item, health_score_setting, health_score_obj_params
                    ):
                        self.log(
                            "Health score setting '{0}' does not require an update".format(
                                name
                            ),
                            "INFO",
                        )

                        if result_health_score_settings.get("msg") is not None:
                            result_health_score_settings["msg"].update(
                                {name: "Health score settings do not require an update"}
                            )
                        continue

                    health_score_params = {
                        "id": item.get("id"),
                        "payload": {
                            "includeForOverallHealth": health_score_setting.get(
                                "include_for_overall_health"
                            ),
                            "thresholdValue": health_score_setting.get(
                                "threshold_value"
                            ),
                            "synchronizeToIssueThreshold": health_score_setting.get(
                                "synchronize_to_issue_threshold"
                            ),
                        },
                    }

                    self.log(
                        "Preparing update for Health score settings '{0}' with params: {1}".format(
                            name, health_score_params
                        ),
                        "DEBUG",
                    )

                    try:
                        response = self.dnac._exec(
                            family="devices",
                            function="update_health_score_definition_for_the_given_id",
                            op_modifies=True,
                            params=health_score_params,
                        )

                        if not response:
                            error_message = "Failed to update health score definition: No response received from DNAC."
                            self.log(error_message, "ERROR")
                            self.set_operation_result("failed", False, error_message, "ERROR").check_return_status()

                        response_data = response.get("response")
                        if response_data:
                            self.log(
                                "Successfully updated Health score settings '{0}' with details: {1}".format(
                                    name, response_data
                                ),
                                "INFO",
                            )
                            updated_health_score_settings.append(response_data)

                        result_health_score_settings.get("response").update(
                            {"Health score details": updated_health_score_settings}
                        )
                        result_health_score_settings.get("msg").update(
                            {
                                response_data.get(
                                    "name"
                                ): "Health score settings updated Successfully"
                            }
                        )
                        self.msg = "Successfully updated Health score settings."
                        self.set_operation_result(
                            "success", True, self.msg, "INFO", self.result["response"]
                        )
                    except Exception as e:
                        e = str(e).split('"')[9]
                        self.msg = "Exception occurred while updating the Health score settings '{0}':'{1}'".format(
                            str(name), str(e)
                        )
                        self.log(self.msg, "ERROR")
                        self.set_operation_result("failed", False, self.msg, "ERROR").check_return_status()

        return self

    def verify_diff_merged(self, config):
        """
        Validating the Cisco Catalyst Center configuration with the playbook details
        when state is merged (Update).

        Parameters:
            config (dict) - Playbook details containing Assurance Health score setting.
              - "device_health_score" (list of dict): The list of Health score settings that need to be validated.

        Returns:
            self - The current object with Assurance Health score information.
            If validation fails the operation is marked as failed and the method returns early with an error message.
        """

        self.all_device_health_score_details = {}
        self.get_have(config)
        self.log("Current State (have): {0}".format(self.have), "INFO")
        self.log(
            "Requested State (want): {0}".format(self.want.get("device_health_score")),
            "INFO",
        )
        device_health_score_list = self.want.get("device_health_score")
        if not device_health_score_list:
            self.log("No device health score settings to validate.", "INFO")
            self.msg = "No Assurance Health score settings provided for validation."
            return self

        self.log(
            "Desired State of assurance Health score issue settings (want): {0}".format(
                device_health_score_list
            ),
            "DEBUG",
        )
        self.log(
            "Current State of assurance Health score issue settings (have): {0}".format(
                self.have
            ),
            "DEBUG",
        )

        for index, item in enumerate(device_health_score_list):
            if index >= len(self.have):
                self.msg = "Mismatch: More device health score settings in 'want' than in 'have'."
                self.set_operation_result("failed", False, self.msg, "ERROR")
                return self

            device_health_score_details = self.have[index]
            health_score_obj_params = self.health_score_obj_params(
                "device_health_score_settings"
            )

            if self.requires_update(
                device_health_score_details, item, health_score_obj_params
            ):
                self.msg = "Assurance Health score Config is not applied to the Cisco Catalyst Center"
                self.set_operation_result("failed", False, self.msg, "ERROR")
                return self

        self.log("Successfully validated Assurance Health score setting(s).", "INFO")
        if isinstance(self.result.get("response"), list) and self.result["response"]:
            self.result["response"][0].setdefault(
                "device_health_score_settings", {}
            ).update({"Validation": "Success"})

        self.msg = "Successfully validated the Assurance user defined issue."
        return self


def main():
    """main entry point for module execution"""
    element_spec = {
        "dnac_host": {"type": "str", "required": True},
        "dnac_port": {"type": "str", "default": "443"},
        "dnac_username": {"type": "str", "default": "admin", "aliases": ["user"]},
        "dnac_password": {"type": "str", "no_log": True},
        "dnac_verify": {"type": "bool", "default": True},
        "dnac_version": {"type": "str", "default": "2.2.3.3"},
        "dnac_debug": {"type": "bool", "default": False},
        "dnac_log": {"type": "bool", "default": False},
        "dnac_log_level": {"type": "str", "default": "WARNING"},
        "dnac_log_file_path": {"type": "str", "default": "dnac.log"},
        "dnac_log_append": {"type": "bool", "default": True},
        "config_verify": {"type": "bool", "default": False},
        "dnac_api_task_timeout": {"type": "int", "default": 1200},
        "dnac_task_poll_interval": {"type": "int", "default": 2},
        "config": {"type": "list", "required": True, "elements": "dict"},
        "state": {"default": "merged", "choices": ["merged"]},
        "validate_response_schema": {"type": "bool", "default": True},
    }

    module = AnsibleModule(argument_spec=element_spec, supports_check_mode=False)

    ccc_assurance = Healthscore(module)
    state = ccc_assurance.params.get("state")

    if state not in ccc_assurance.supported_states:
        ccc_assurance.status = "invalid"
        ccc_assurance.msg = "State '{0}' is invalid. Supported states: {1}".format
        (state, ", ".join(ccc_assurance.supported_states))
        ccc_assurance.check_return_status()

    ccc_version = ccc_assurance.get_ccc_version()
    if ccc_assurance.compare_dnac_versions(ccc_version, "2.3.7.9") < 0:
        ccc_assurance.msg = (
            "The specified version '{0}' does not support the Assurance Health Score features. "
            "Supported versions start from '2.3.7.9' onwards.".format(ccc_version)
        )
        ccc_assurance.status = "failed"
        ccc_assurance.check_return_status()
    ccc_assurance.validate_input().check_return_status()
    config_verify = ccc_assurance.params.get("config_verify")

    for config in ccc_assurance.validated_config:
        ccc_assurance.input_data_validation(config).check_return_status()
        ccc_assurance.get_want(config).check_return_status()
        ccc_assurance.get_have(config).check_return_status()
        ccc_assurance.get_diff_state_apply[state](config).check_return_status()
        if config_verify:
            ccc_assurance.verify_diff_state_apply[state](config).check_return_status()

    module.exit_json(**ccc_assurance.result)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_rogue_wireless_containment_status_info
short_description: Information module for Security Rogue
  Wireless-Containment Status
description:
  - Get Security Rogue Wireless-Containment Status by
    id. - > Intent API to check the wireless rogue access
    point containment status. The response includes
    all the details like containment status, contained
    by WLC, containment status of each BSSID etc. This
    API also includes the information of strongest detecting
    WLC for this rogue access point.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  macAddress:
    description:
      - MacAddress path parameter. MAC Address of the
        Wireless Rogue AP.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      WirelessRogueAPContainmentStatus
    description: Complete reference of the WirelessRogueAPContainmentStatus
      API.
    link: https://developer.cisco.com/docs/dna-center/#!wireless-rogue-ap-containment-status
notes:
  - SDK Method used are
    devices.Devices.wireless_rogue_ap_containment_status,
  - Paths used are
    get /dna/intent/api/v1/security/rogue/wireless-containment/status/{macAddress},
"""

EXAMPLES = r"""
---
- name: Get Security Rogue Wireless-Containment Status
    by id
  cisco.dnac.security_rogue_wireless-containment_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    macAddress: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "macAddress": "string",
          "type": 0,
          "classification": "string",
          "containmentStatus": "string",
          "containedByWlcIp": [
            "string"
          ],
          "lastSeen": 0,
          "strongestDetectingWlcIp": "string",
          "lastTaskDetail": {
            "taskId": "string",
            "taskType": "string",
            "taskState": "string",
            "taskStartTime": 0,
            "initiatedOnWlcIp": "string",
            "initiatedOnBssid": [
              "string"
            ]
          },
          "bssidContainmentStatus": [
            {
              "bssid": "string",
              "ssid": "string",
              "radioType": "string",
              "containmentStatus": "string",
              "containedByWlcIp": "string",
              "isAdhoc": true
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_rogue_additional_details_count
short_description: Resource module for Security Rogue
  Additional Details Count
description:
  - Manage operation create of the resource Security
    Rogue Additional Details Count.
  - This API returns the count for the Rogue Additional
    Details.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: This is the epoch end time in milliseconds
      upto which data need to be fetched. Default value
      is current time.
    type: float
  siteId:
    description: Filter Rogues by location. Site IDs
      information can be fetched from "Get Site" API.
    elements: str
    type: list
  startTime:
    description: This is the epoch start time in milliseconds
      from which data need to be fetched. Default value
      is 24 hours earlier to endTime.
    type: float
  threatLevel:
    description: This information can be fetched from
      "Get Threat Levels" API.
    elements: str
    type: list
  threatType:
    description: This information can be fetched from
      "Get Threat Types" API.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RogueAdditionalDetailCount
    description: Complete reference of the RogueAdditionalDetailCount
      API.
    link: https://developer.cisco.com/docs/dna-center/#!rogue-additional-detail-count
notes:
  - SDK Method used are
    devices.Devices.rogue_additional_detail_count,
  - Paths used are
    post /dna/intent/api/v1/security/rogue/additional/details/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_rogue_additional_details_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    siteId:
      - string
    startTime: 0
    threatLevel:
      - string
    threatType:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_authentication_profiles
short_description: Resource module for Sda Authentication
  Profiles
description:
  - Manage operation update of the resource Sda Authentication
    Profiles.
  - Updates an authentication profile based on user
    input.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Sda Authentication Profiles's payload.
    elements: dict
    suboptions:
      authenticationOrder:
        description: First authentication method.
        type: str
      authenticationProfileName:
        description: The default host authentication
          template (updating this field is not allowed).
        type: str
      dot1xToMabFallbackTimeout:
        description: 802.1x Timeout.
        type: int
      fabricId:
        description: ID of the fabric this authentication
          profile is assigned to (updating this field
          is not allowed). To update a global authentication
          profile, either remove this property or set
          its value to null.
        type: str
      id:
        description: ID of the authentication profile
          (updating this field is not allowed).
        type: str
      isBpduGuardEnabled:
        description: Enable/disable BPDU Guard. Only
          applicable when authenticationProfileName
          is set to "Closed Authentication" (defaults
          to true).
        type: bool
      isVoiceVlanEnabled:
        description: Enable/disable Voice Vlan.
        type: bool
      numberOfHosts:
        description: Number of Hosts.
        type: str
      preAuthAcl:
        description: Sda Authentication Profiles's preAuthAcl.
        suboptions:
          accessContracts:
            description: Sda Authentication Profiles's
              accessContracts.
            elements: dict
            suboptions:
              action:
                description: Contract behaviour.
                type: str
              port:
                description: Port for the access contract.
                  The port can only be used once in
                  the Access Contract list.
                type: str
              protocol:
                description: Protocol for the access
                  contract. "TCP" and "TCP_UDP" are
                  only allowed when the contract port
                  is "domain".
                type: str
            type: list
          description:
            description: Description of this Pre-Authentication
              ACL.
            type: str
          enabled:
            description: Enable/disable Pre-Authentication
              ACL.
            type: bool
          implicitAction:
            description: Implicit behaviour unless overridden
              (defaults to "DENY").
            type: str
        type: dict
      wakeOnLan:
        description: Wake on LAN.
        type: bool
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA UpdateAuthenticationProfile
    description: Complete reference of the UpdateAuthenticationProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-authentication-profile
notes:
  - SDK Method used are
    sda.Sda.update_authentication_profile,
  - Paths used are
    put /dna/intent/api/v1/sda/authenticationProfiles,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.sda_authentication_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - authenticationOrder: string
        authenticationProfileName: string
        dot1xToMabFallbackTimeout: 0
        fabricId: string
        id: string
        isBpduGuardEnabled: true
        isVoiceVlanEnabled: true
        numberOfHosts: string
        preAuthAcl:
          accessContracts:
            - action: string
              port: string
              protocol: string
          description: string
          enabled: true
          implicitAction: string
        wakeOnLan: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_device_controllability_settings_info
short_description: Information module for Network Devices
  Device Controllability Settings
description:
  - Get all Network Devices Device Controllability Settings.
    - > Device Controllability is a system-level process
    on Catalyst Center that enforces state synchronization
    for some device-layer features. Its purpose is to
    aid in the deployment of required network settings
    that Catalyst Center needs to manage devices. Changes
    are made on network devices during discovery, when
    adding a device to Inventory, or when assigning
    a device to a site. If changes are made to any settings
    that are under the scope of this process, these
    changes are applied to the network devices during
    the Provision and Update Telemetry Settings operations,
    even if Device Controllability is disabled. The
    following device settings will be enabled as part
    of Device Controllability when devices are discovered.
    - SNMP Credentials. - NETCONF Credentials. Subsequent
    to discovery, devices will be added to Inventory.
    The following device settings will be enabled when
    devices are added to inventory. - Cisco TrustSec
    CTS Credentials. The following device settings will
    be enabled when devices are assigned to a site.
    Some of these settings can be defined at a site
    level under Design > Network Settings > Telemetry
    & Wireless. - Wired Endpoint Data Collection Enablement.
    - Controller Certificates. - SNMP Trap Server Definitions.
    - Syslog Server Definitions. - Application Visibility.
    - Application QoS Policy. - Wireless Service Assurance
    WSA. - Wireless Telemetry. - DTLS Ciphersuite. -
    AP Impersonation. If Device Controllability is disabled,
    Catalyst Center does not configure any of the preceding
    credentials or settings on devices during discovery,
    at runtime, or during site assignment. However,
    the telemetry settings and related configuration
    are pushed when the device is provisioned or when
    the update Telemetry Settings action is performed.
    Catalyst Center identifies and automatically corrects
    the following telemetry configuration issues on
    the device. - SWIM certificate issue. - IOS WLC
    NA certificate issue. - PKCS12 certificate issue.
    - IOS telemetry configuration issu.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      GetDeviceControllabilitySettings
    description: Complete reference of the GetDeviceControllabilitySettings
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-device-controllability-settings
notes:
  - SDK Method used are
    site_design.SiteDesign.get_device_controllability_settings,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/deviceControllability/settings,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Device Controllability
    Settings
  cisco.dnac.network_devices_device_controllability_settings_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "autocorrectTelemetryConfig": true,
        "deviceControllability": true
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_kpi_summaries_info
short_description: Information module for Site Kpi Summaries
description:
  - Get all Site Kpi Summaries. - > Returns site analytics
    for all child sites of given parent site. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    SiteKpiSummaries-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously
        processed & stored data. When this parameter
        is used, the rest of the request params will
        be ignored.
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site.
        A site can be an area, building, or floor. Default
        when not provided will be `floor,building,area`
        Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor`
        (multiple siteTypes requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. SSID is the name of wireless
        network to which client connects to. It is also
        referred to as WLAN ID - Wireless Local Area
        Network Identifier. Examples `ssid=Alpha` (single
        ssid requested) `ssid=Alpha&ssid=Guest` (multiple
        ssid requested).
    type: str
  band:
    description:
      - >
        Band query parameter. WiFi frequency band that
        client or Access Point operates. Band value
        is represented in Giga Hertz - GHz Examples
        `band=5` (single band requested) `band=2.4&band=6`
        (multiple band requested).
    type: str
  failureCategory:
    description:
      - >
        FailureCategory query parameter. Category of
        failure when a client fails to meet the threshold.
        Examples `failureCategory=AUTH` (single failure
        category requested) `failureCategory=AUTH&failureCategory=DHCP`
        (multiple failure categories requested).
    type: str
  failureReason:
    description:
      - >
        FailureReason query parameter. Reason for failure
        when a client fails to meet the threshold. Examples
        `failureReason=MOBILITY_FAILURE` (single ssid
        requested) `failureReason=REASON_IPLEARN_CONNECT_TIMEOUT&failureReason=ST_EAP_TIMEOUT`
        (multiple ssid requested).
    type: str
  view:
    description:
      - >
        View query parameter. <p>The name of the View.
        Each view represents a specific data set. Please
        refer to the <code>SiteAnalyticsView</code>
        Model for supported views. View is predefined
        set of attributes supported by the API. Only
        the attributes related to the given view will
        be part of the API response along with default
        attributes. If multiple views are provided,
        then response will contain attributes from all
        those views. If no views are specified, all
        attributes will be returned.</p><table><thead><tr><th>View
        Name</th><th>Included Attributes</th></tr></thead><tbody><tr><td><code>coverage</code></td><td>coverageAverage,
        coverageSuccessPercentage, coverageSuccessCount,
        coverageTotalCount, coverageFailureCount, coverageClientCount,
        coverageImpactedEntities, coverageFailureImpactedEntities,
        coverageFailureMetrics</ td></tr><tr><td><code>onboardingAttempts</code></td><td>onboardingAttemptsSuccessPercentage,
        onboardingAttemptsSuccessCount, onboardingAttemptsTotalCount,
        onboardingAttemptsFailureCount, onboardingAttemptsClientCount,
        onboardingAttemptsImpactedEntities, onboardingAttemptsFailureImpactedEntities,
        onboardingAttemptsFailureMetrics</td></tr><tr><td><code>onboa
        rdingDuration</code></td><td>onboardingDurationAverage,
        onboardingDurationSuccessPercentage, onboardingDurationSuccessCount,
        onboardingDurationTotalCount, onboardingDurationFailureCount,
        onboardingDurationClientCount, onboardingDurationImpactedEntities,
        onboardingDurationFailureImpactedEntities, onboardingDurationFailureMetrics</td></tr><tr><td><code>roami
        ngAttempts</code></td><td>roamingAttemptsSuccessPercentage,
        roamingAttemptsSuccessCount, roamingAttemptsTotalCount,
        roamingAttemptsFailureCount, roamingAttemptsClientCount,
        roamingAttemptsImpactedEntities, roamingAttemptsFailureImpactedEntities,
        roamingAttemptsFailureMetrics</ td></tr><tr><td><code>roamingDuration</code></td><td>roamingDurationAverage,
        roamingDurationSuccessPercentage, roamingDurationSuccessCount,
        roamingDurationTotalCount, roamingDurationFailureCount,
        roamingDurationClientCount, roamingDurationImpactedEntities,
        roamingDurationFailureImpactedEntities, roamingDurationFailureMetrics</td></tr><tr><td><code>connectionS
        peed</code></td><td>connectionSpeedAverage,
        connectionSpeedSuccessPercentage, connectionSpeedSuccessCount,
        connectionSpeedTotalCount, connectionSpeedFailureCount,
        connectionSpeedClientCount, connectionSpeedImpactedEntities,
        connectionSpeedFailureImpactedEntities, connectionSpeedFailureMetrics</td></tr></tbody></table><p>Examples
        <code>view=connectionSpeed</code> (single view
        requested) <code>view=roamingDuration&amp;view=roamingAttempts</code>
        (multiple views requested) </p>.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes
        related to site analytics. If these are provided,
        then only those attributes will be part of response
        along with the default attributes. Examples
        `attribute=coverageAverage` (single attribute
        requested) `attribute=coverageFailureMetrics&attribute=coverageTotalCount`
        (multiple attributes requested).
    type: str
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  sortBy:
    description:
      - SortBy query parameter. Field name on which
        sorting needs to be done.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sites GetSiteAnalyticsForTheChildSitesOfGivenParentSiteAndOtherQueryParameters
    description: Complete reference of the GetSiteAnalyticsForTheChildSitesOfGivenParentSiteAndOtherQueryParameters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-analytics-for-the-child-sites-of-given-parent-site-and-other-query-parameters
notes:
  - SDK Method used are
    sites.Sites.get_site_analytics_for_the_child_sites_of_given_parent_site_and_other_query_parameters,
  - Paths used are
    get /dna/data/api/v1/siteKpiSummaries,
"""

EXAMPLES = r"""
---
- name: Get all Site Kpi Summaries
  cisco.dnac.site_kpi_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    siteType: string
    ssid: string
    band: string
    failureCategory: string
    failureReason: string
    view: string
    attribute: string
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "siteId": "string",
          "siteHierarchyId": "string",
          "siteHierarchy": "string",
          "siteType": "string",
          "apCount": 0,
          "coverageAverage": 0,
          "coverageSuccessPercentage": 0,
          "coverageSuccessCount": 0,
          "coverageTotalCount": 0,
          "coverageFailureCount": 0,
          "coverageClientCount": 0,
          "coverageImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "coverageFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "coverageFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          },
          "onboardingAttemptsSuccessPercentage": 0,
          "onboardingAttemptsSuccessCount": 0,
          "onboardingAttemptsTotalCount": 0,
          "onboardingAttemptsFailureCount": 0,
          "onboardingAttemptsClientCount": 0,
          "onboardingAttemptsImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "onboardingAttemptsFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "onboardingAttemptsFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          },
          "onboardingDurationAverage": 0,
          "onboardingDurationSuccessPercentage": 0,
          "onboardingDurationSuccessCount": 0,
          "onboardingDurationTotalCount": 0,
          "onboardingDurationFailureCount": 0,
          "onboardingDurationClientCount": 0,
          "onboardingDurationImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "onboardingDurationFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "onboardingDurationFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          },
          "roamingAttemptsSuccessPercentage": 0,
          "roamingAttemptsSuccessCount": 0,
          "roamingAttemptsTotalCount": 0,
          "roamingAttemptsFailureCount": 0,
          "roamingAttemptsClientCount": 0,
          "roamingAttemptsImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "roamingAttemptsFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "roamingAttemptsFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          },
          "roamingDurationAverage": 0,
          "roamingDurationSuccessPercentage": 0,
          "roamingDurationSuccessCount": 0,
          "roamingDurationTotalCount": 0,
          "roamingDurationFailureCount": 0,
          "roamingDurationClientCount": 0,
          "roamingDurationImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "roamingDurationFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "roamingDurationFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          },
          "connectionSpeedAverage": 0,
          "connectionSpeedSuccessPercentage": 0,
          "connectionSpeedSuccessCount": 0,
          "connectionSpeedTotalCount": 0,
          "connectionSpeedFailureCount": 0,
          "connectionSpeedClientCount": 0,
          "connectionSpeedImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "connectionSpeedFailureImpactedEntities": {
            "buildingCount": 0,
            "floorCount": 0,
            "sitesCount": 0,
            "apCount": 0
          },
          "connectionSpeedFailureMetrics": {
            "failureApCount": 0,
            "failureClientCount": 0,
            "failurePercentage": 0
          }
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": {
          "name": "string",
          "order": "string"
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_licenses_network_device_id_port_channels_info
short_description: Information module for Network Device
  Licenses Network Device Id Port Channels
description:
  - Get all Network Device Licenses Network Device Id
    Port Channels.
  - This API endpoint retrieves the list of port channels
    for the given network device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId path parameter. Unique identifier
        for the network device.
    type: str
  id:
    description:
      - Id query parameter. Optional list of the port
        channel ids to filter by.
    type: str
  name:
    description:
      - >
        Name query parameter. Optional name of the port
        channel to filter by. This supports partial
        search. For example, searching for "Port" will
        match "Port-channel1", "Port-channel2", etc.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RetrievesTheListOfPortChannelsForTheNetworkDevice
    description: Complete reference of the RetrievesTheListOfPortChannelsForTheNetworkDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-port-channels-for-the-network-device
notes:
  - SDK Method used are
    devices.Devices.retrieves_the_list_of_port_channels_for_the_network_device,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/{networkDeviceId}/portChannels,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Licenses Network Device
    Id Port Channels
  cisco.dnac.network_device_licenses_network_device_id_port_channels_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    name: string
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "aggregationProtocol": "string",
          "logicalSlotPort": "string",
          "interfaces": {
            "name": "string",
            "channelMode": "string"
          },
          "networkDeviceId": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_distribute_bulk
short_description: Resource module for Network Device
  Images Distribute Bulk
description:
  - Manage operation create of the resource Network
    Device Images Distribute Bulk. - > This API initiates
    the process of distributing the software image on
    the given network devices. Providing value for the
    `distributedImages` will only trigger the distribution
    process. To monitor the progress and completion
    of the update task, please call the GET API `/dna/intent/api/v1/networkDeviceImageUpdates?parentId={taskId}`,
    where `taskId` is from the response of the current
    endpoint.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Network Device Images Distribute Bulk's
      payload.
    elements: dict
    suboptions:
      distributedImages:
        description: Network Device Images Distribute
          Bulk's distributedImages.
        elements: dict
        suboptions:
          id:
            description: Software image identifier.
            type: str
        type: list
      id:
        description: Network device identifier.
        type: str
      networkValidationIds:
        description: List of unique identifier of custom
          network device validations.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) BulkDistributeImagesOnNetworkDevices
    description: Complete reference of the BulkDistributeImagesOnNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!bulk-distribute-images-on-network-devices
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.bulk_distribute_images_on_network_devices,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceImages/distribute/bulk,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_images_distribute_bulk:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    payload:
      - distributedImages:
          - id: string
        id: string
        networkValidationIds:
          - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: event_subscription_email
short_description: Resource module for Event Subscription
  Email
description:
  - Manage operations create and update of the resource
    Event Subscription Email.
  - Create Email Subscription Endpoint for list of registered
    events.
  - Update Email Subscription Endpoint for list of registered
    events.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Event Subscription Email's payload.
    elements: dict
    suboptions:
      description:
        description: Description.
        type: str
      filter:
        description: Event Subscription Email's filter.
        suboptions:
          categories:
            description: Categories.
            elements: str
            type: list
          domainsSubdomains:
            description: Event Subscription Email's
              domainsSubdomains.
            elements: dict
            suboptions:
              domain:
                description: Domain.
                type: str
              subDomains:
                description: Sub Domains.
                elements: str
                type: list
            type: list
          eventIds:
            description: Event Ids.
            elements: str
            type: list
          severities:
            description: Severities.
            elements: int
            type: list
          siteIds:
            description: Site Ids.
            elements: str
            type: list
          sources:
            description: Sources.
            elements: str
            type: list
          types:
            description: Types.
            elements: str
            type: list
        type: dict
      name:
        description: Name.
        type: str
      subscriptionEndpoints:
        description: Event Subscription Email's subscriptionEndpoints.
        elements: dict
        suboptions:
          instanceId:
            description: (From Get Email Subscription
              Details --> pick InstanceId if available).
            type: str
          subscriptionDetails:
            description: Event Subscription Email's
              subscriptionDetails.
            suboptions:
              connectorType:
                description: Connector Type (Must be
                  EMAIL).
                type: str
              description:
                description: Description.
                type: str
              fromEmailAddress:
                description: Senders Email Address.
                type: str
              name:
                description: Name.
                type: str
              subject:
                description: Email Subject.
                type: str
              toEmailAddresses:
                description: Recipient's Email Addresses
                  (Comma separated).
                elements: str
                type: list
            type: dict
        type: list
      subscriptionId:
        description: Subscription Id (Unique UUID).
        type: str
      version:
        description: Version.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Event Management
      CreateEmailEventSubscription
    description: Complete reference of the CreateEmailEventSubscription
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-email-event-subscription
  - name: Cisco DNA Center documentation for Event Management
      UpdateEmailEventSubscription
    description: Complete reference of the UpdateEmailEventSubscription
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-email-event-subscription
notes:
  - SDK Method used are
    event_management.EventManagement.create_email_event_subscription,
    event_management.EventManagement.update_email_event_subscription,
  - Paths used are
    post /dna/intent/api/v1/event/subscription/email,
    put /dna/intent/api/v1/event/subscription/email,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.event_subscription_email:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - description: string
        filter:
          categories:
            - string
          domainsSubdomains:
            - domain: string
              subDomains:
                - string
          eventIds:
            - string
          severities:
            - 0
          siteIds:
            - string
          sources:
            - string
          types:
            - string
        name: string
        subscriptionEndpoints:
          - instanceId: string
            subscriptionDetails:
              connectorType: string
              description: string
              fromEmailAddress: string
              name: string
              subject: string
              toEmailAddresses:
                - string
        subscriptionId: string
        version: string
- name: Update all
  cisco.dnac.event_subscription_email:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - description: string
        filter:
          categories:
            - string
          domainsSubdomains:
            - domain: string
              subDomains:
                - string
          eventIds:
            - string
          severities:
            - 0
          siteIds:
            - string
          sources:
            - string
          types:
            - string
        name: string
        subscriptionEndpoints:
          - instanceId: string
            subscriptionDetails:
              connectorType: string
              description: string
              fromEmailAddress: string
              name: string
              subject: string
              toEmailAddresses:
                - string
        subscriptionId: string
        version: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "statusUri": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_multicast_virtual_networks
short_description: Resource module for Sda Multicast
  Virtual Networks
description:
  - Manage operations create, update and delete of the
    resource Sda Multicast Virtual Networks.
  - Adds multicast for virtual networks based on user
    input.
  - Deletes a multicast configuration for a virtual
    network based on id.
  - Updates multicast configurations for virtual networks
    based on user input.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. ID of the multicast
      configuration.
    type: str
  payload:
    description: Sda Multicast Virtual Networks's payload.
    elements: dict
    suboptions:
      fabricId:
        description: ID of the fabric site this multicast
          configuration is associated with.
        type: str
      ipPoolName:
        description: Name of the IP Pool associated
          with the fabric site.
        type: str
      ipv4SsmRanges:
        description: IPv4 Source Specific Multicast
          (SSM) ranges. Allowed ranges are from 225.0.0.0/8
          to 239.0.0.0/8. SSM ranges should not conflict
          with ranges provided for ASM multicast.
        elements: str
        type: list
      multicastRPs:
        description: Sda Multicast Virtual Networks's
          multicastRPs.
        elements: dict
        suboptions:
          ipv4Address:
            description: IPv4 address of the RP. For
              external RP configuration, exactly one
              of ipv4Address or ipv6Address must be
              provided. For fabric RP, this address
              is allocated by SDA and should not be
              provided during RP creation request and
              SDA allocated address should be retained
              in subsequent requests.
            type: str
          ipv4AsmRanges:
            description: IPv4 Any Source Multicast ranges.
              Comma seperated list of IPv4 multicast
              group ranges that will be served by a
              given Multicast RP. Only IPv4 ranges can
              be provided. For fabric RP, both IPv4
              and IPv6 ranges can be provided together.
              For external RP, IPv4 ranges should be
              provided for IPv4 external RP and IPv6
              ranges should be provided for IPv6 external
              RP.
            elements: str
            type: list
          ipv6Address:
            description: IPv6 address of the RP. For
              external RP configuration, exactly one
              of ipv4Address or ipv6Address must be
              provided. For fabric RP, this address
              is allocated by SDA and should not be
              provided during RP creation request and
              SDA allocated address should be retained
              in subsequent requests. Ipv6Address can
              only be provided for virtual networks
              with dual stack (IPv4 + IPv6) multicast
              pool.
            type: str
          ipv6AsmRanges:
            description: IPv6 Any Source Multicast ranges.
              Comma seperated list of IPv6 multicast
              group ranges that will be served by a
              given Multicast RP. Only IPv6 ranges can
              be provided. IPv6 ranges can only be provided
              for dual stack multicast pool. For fabric
              RP, both IPv4 and IPv6 ranges can be provided
              together. For external RP, IPv4 ranges
              should be provided for IPv4 external RP
              and IPv6 ranges should be provided for
              IPv6 external RP.
            elements: str
            type: list
          isDefaultV4RP:
            description: Specifies whether it is a default
              IPv4 RP.
            type: bool
          isDefaultV6RP:
            description: Specifies whether it is a default
              IPv6 RP.
            type: bool
          networkDeviceIds:
            description: IDs of the network devices.
              This is a required field for fabric RPs.
              There can be maximum of two fabric RPs
              for a fabric site and these are shared
              across all multicast virtual networks.
              For configuring two fabric RPs in a fabric
              site both devices must have border roles.
              Only one RP can be configured in scenarios
              where a fabric edge device is used as
              RP or a dual stack multicast pool is used.
            elements: str
            type: list
          rpDeviceLocation:
            description: Device location of the RP.
            type: str
        type: list
      virtualNetworkName:
        description: Name of the virtual network associated
          with the fabric site.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA AddMulticastVirtualNetworks
    description: Complete reference of the AddMulticastVirtualNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-multicast-virtual-networks
  - name: Cisco DNA Center documentation for SDA DeleteMulticastVirtualNetworkById
    description: Complete reference of the DeleteMulticastVirtualNetworkById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-multicast-virtual-network-by-id
  - name: Cisco DNA Center documentation for SDA UpdateMulticastVirtualNetworks
    description: Complete reference of the UpdateMulticastVirtualNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-multicast-virtual-networks
notes:
  - SDK Method used are
    sda.Sda.add_multicast_virtual_networks,
    sda.Sda.delete_multicast_virtual_network_by_id,
    sda.Sda.update_multicast_virtual_networks,
  - Paths used are
    post /dna/intent/api/v1/sda/multicast/virtualNetworks,
    delete /dna/intent/api/v1/sda/multicast/virtualNetworks/{id},
    put /dna/intent/api/v1/sda/multicast/virtualNetworks,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.sda_multicast_virtual_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - fabricId: string
        ipPoolName: string
        ipv4SsmRanges:
          - string
        multicastRPs:
          - ipv4Address: string
            ipv4AsmRanges:
              - string
            ipv6Address: string
            ipv6AsmRanges:
              - string
            isDefaultV4RP: true
            isDefaultV6RP: true
            networkDeviceIds:
              - string
            rpDeviceLocation: string
        virtualNetworkName: string
- name: Update all
  cisco.dnac.sda_multicast_virtual_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - fabricId: string
        id: string
        ipPoolName: string
        ipv4SsmRanges:
          - string
        multicastRPs:
          - ipv4Address: string
            ipv4AsmRanges:
              - string
            ipv6Address: string
            ipv6AsmRanges:
              - string
            isDefaultV4RP: true
            isDefaultV6RP: true
            networkDeviceIds:
              - string
            rpDeviceLocation: string
        virtualNetworkName: string
- name: Delete by id
  cisco.dnac.sda_multicast_virtual_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_spectrum_sensor_reports_info
short_description: Information module for Icap Spectrum
  Sensor Reports
description:
  - Get all Icap Spectrum Sensor Reports. - > Retrieves
    the spectrum sensor reports sent by WLC for provided
    AP Mac. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-icap-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  apMac:
    description:
      - ApMac query parameter. The base ethernet macAddress
        of the access point.
    type: str
  dataType:
    description:
      - >
        DataType query parameter. Data type reported
        by the sensor |Data Type | Description | | ---
        | --- | | `0` | Duty Cycle | | `1` | Max Power
        | | `2` | Average Power | | `3` | Max Power
        in dBm with adjusted base of +48 | | `4` | Average
        Power in dBm with adjusted base of +48 |.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: int
  timeSortOrder:
    description:
      - TimeSortOrder query parameter. The sort order
        of the field ascending or descending.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sensors
      RetrievesTheSpectrumSensorReportsSentByWLCForProvidedAPMac
    description: Complete reference of the RetrievesTheSpectrumSensorReportsSentByWLCForProvidedAPMac
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-spectrum-sensor-reports-sent-by-wlc-for-provided-ap-mac
notes:
  - SDK Method used are
    sensors.Sensors.retrieves_the_spectrum_sensor_reports_sent_by_w_l_c_for_provided_ap_mac,
  - Paths used are
    get /dna/data/api/v1/icap/spectrumSensorReports,
"""

EXAMPLES = r"""
---
- name: Get all Icap Spectrum Sensor Reports
  cisco.dnac.icap_spectrum_sensor_reports_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    apMac: string
    dataType: 0
    limit: 0
    offset: 0
    timeSortOrder: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "spanKHz": 0,
          "dataType": 0,
          "apMac": "string",
          "dataAvg": 0,
          "dataMin": 0,
          "dataMax": 0,
          "dataUnits": "string",
          "centralFrequencyKHz": 0,
          "band": "string",
          "timestamp": 0,
          "data": [
            0
          ],
          "dataSize": 0,
          "channels": [
            0
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: license_device_license_details_info
short_description: Information module for License Device
  License Details
description:
  - Get all License Device License Details.
  - Get detailed license information of a device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  device_uuid:
    description:
      - Device_uuid path parameter. Id of device.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Licenses
      DeviceLicenseDetails
    description: Complete reference of the DeviceLicenseDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!device-license-details
notes:
  - SDK Method used are
    licenses.Licenses.device_license_details,
  - Paths used are
    get /dna/intent/api/v1/licenses/device/{device_uuid}/details,
"""

EXAMPLES = r"""
---
- name: Get all License Device License Details
  cisco.dnac.license_device_license_details_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    device_uuid: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample:
  - {}
"""
